# django-simple-nav

```{include} ../README.md
:start-after: <!-- intro-start -->
:end-before: <!-- intro-end -->
```

```{toctree}
:hidden:
:maxdepth: 3

getting-started.md
usage.md
changelog.md
```

```{toctree}
:hidden:
:maxdepth: 3
:caption: Reference

apidocs/index.rst
```

```{toctree}
:hidden:
:maxdepth: 3
:caption: Development

development/contributing.md
development/just.md
development/releasing.md
```
